# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_primary_analysis import ReportingPrimaryAnalysis

class TestReportingPrimaryAnalysis(unittest.TestCase):
    """ReportingPrimaryAnalysis unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPrimaryAnalysis:
        """Test ReportingPrimaryAnalysis
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPrimaryAnalysis`
        """
        model = ReportingPrimaryAnalysis()
        if include_optional:
            return ReportingPrimaryAnalysis(
                exploration_topics = [
                    neurograph.v1.models.reporting/exploration_topic.reporting.ExplorationTopic(
                        context = {
                            'key' : None
                            }, 
                        query = '', 
                        title = '', )
                    ],
                key_findings = [
                    ''
                    ],
                summary = ''
            )
        else:
            return ReportingPrimaryAnalysis(
        )
        """

    def testReportingPrimaryAnalysis(self):
        """Test ReportingPrimaryAnalysis"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
