# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest

class TestKnowledgeEnrichmentArtifactCreateRequest(unittest.TestCase):
    """KnowledgeEnrichmentArtifactCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEnrichmentArtifactCreateRequest:
        """Test KnowledgeEnrichmentArtifactCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEnrichmentArtifactCreateRequest`
        """
        model = KnowledgeEnrichmentArtifactCreateRequest()
        if include_optional:
            return KnowledgeEnrichmentArtifactCreateRequest(
                client_id = 'cli_1234',
                cloud_run_job_name = '',
                confidence = 1.337,
                config_entity_id = '',
                config_snapshot = None,
                input_params = None,
                job_name = 'customer_profile_v1',
                kind = '',
                output_json = None,
                output_schema_id = '',
                output_text = '',
                spec_version = 1,
                subject_entity_id = 'ent_123',
                supersedes_artifact_id = 56,
                task_name = '',
                task_queue_name = ''
            )
        else:
            return KnowledgeEnrichmentArtifactCreateRequest(
        )
        """

    def testKnowledgeEnrichmentArtifactCreateRequest(self):
        """Test KnowledgeEnrichmentArtifactCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
