# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_visualization import ReportingVisualization

class TestReportingVisualization(unittest.TestCase):
    """ReportingVisualization unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingVisualization:
        """Test ReportingVisualization
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingVisualization`
        """
        model = ReportingVisualization()
        if include_optional:
            return ReportingVisualization(
                data = neurograph.v1.models.reporting/chart_data.reporting.ChartData(
                    datasets = [
                        neurograph.v1.models.reporting/chart_dataset.reporting.ChartDataset(
                            background_color = '', 
                            bar_percentage = 1.337, 
                            label = '', )
                        ], 
                    labels = [
                        ''
                        ], ),
                id = '',
                insights = neurograph.v1.models.reporting/visualization_insights.reporting.VisualizationInsights(
                    bullets = [
                        ''
                        ], 
                    summary = '', 
                    title = '', ),
                title = '',
                type = ''
            )
        else:
            return ReportingVisualization(
        )
        """

    def testReportingVisualization(self):
        """Test ReportingVisualization"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
