# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.reporting_api import ReportingApi


class TestReportingApi(unittest.TestCase):
    """ReportingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportingApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_reporting_affinities_get(self) -> None:
        """Test case for api_v1_reporting_affinities_get

        Get customer affinities
        """
        pass

    def test_api_v1_reporting_client_uid_get(self) -> None:
        """Test case for api_v1_reporting_client_uid_get

        Get AI Summary by Client UID
        """
        pass

    def test_api_v1_reporting_customer_activity_get(self) -> None:
        """Test case for api_v1_reporting_customer_activity_get

        Get customer activity metrics
        """
        pass

    def test_api_v1_reporting_daily_rollup_post(self) -> None:
        """Test case for api_v1_reporting_daily_rollup_post

        Get Daily Metrics for Client by Persona
        """
        pass

    def test_api_v1_reporting_persona_activity_get(self) -> None:
        """Test case for api_v1_reporting_persona_activity_get

        Get persona activity trend
        """
        pass

    def test_api_v1_reporting_personas_legacy_get(self) -> None:
        """Test case for api_v1_reporting_personas_legacy_get

        Get persona rollup
        """
        pass


if __name__ == '__main__':
    unittest.main()
