# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi


class TestOrganizationMetadataApi(unittest.TestCase):
    """OrganizationMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_organization_metadata_org_id_delete(self) -> None:
        """Test case for api_v1_organization_metadata_org_id_delete

        Delete an organization's metadata row
        """
        pass

    def test_api_v1_organization_metadata_org_id_get(self) -> None:
        """Test case for api_v1_organization_metadata_org_id_get

        Get organization's metadata rows
        """
        pass

    def test_api_v1_organization_metadata_org_id_post(self) -> None:
        """Test case for api_v1_organization_metadata_org_id_post

        Upsert a organization's metadata
        """
        pass


if __name__ == '__main__':
    unittest.main()
