# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.organization_api import OrganizationApi


class TestOrganizationApi(unittest.TestCase):
    """OrganizationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_organizations_branding_post(self) -> None:
        """Test case for api_v1_organizations_branding_post

        Set an Organization's Branding
        """
        pass

    def test_api_v1_organizations_get(self) -> None:
        """Test case for api_v1_organizations_get

        Get Organizations
        """
        pass

    def test_api_v1_organizations_org_id_get(self) -> None:
        """Test case for api_v1_organizations_org_id_get

        Get Organization by ID or UID
        """
        pass

    def test_api_v1_organizations_org_id_users_get(self) -> None:
        """Test case for api_v1_organizations_org_id_users_get

        Organization's assigned users and their permissions
        """
        pass

    def test_api_v1_organizations_post(self) -> None:
        """Test case for api_v1_organizations_post

        Create an Organization
        """
        pass

    def test_api_v1_organizations_put(self) -> None:
        """Test case for api_v1_organizations_put

        Update an Organization
        """
        pass

    def test_api_v1_organizations_workbench_post(self) -> None:
        """Test case for api_v1_organizations_workbench_post

        Set Organization's Workbench Version
        """
        pass


if __name__ == '__main__':
    unittest.main()
